@@ -1,11 +1,14 @@
 # -*- coding: utf-8 -*-
 
 import ootools, uno
+import os, os.path
 
 # Workaround for a bug in ootools
 from com.sun.star.beans import PropertyValue
 ootools.PropertyValue = PropertyValue
 
+## TODO: rozważyć przejście na unoconv
+
 class Doc2RtfConverter(object):
 
     def __init__(self):
@@ -20,6 +23,8 @@ class Doc2RtfConverter(object):
         #desktop = self.runner.connect()
         document = self.desktop.loadComponentFromURL(
             input_url, "_blank", 0, ootools.oo_properties())
+        if not document:
+            raise Exception("Can't load document (wrong doc?) from %s" % input_file) #input_url)
         try:
             document.storeToURL(output_url, props)
         finally:
